import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../LexModelsV2Client";
import { ListBotReplicasRequest, ListBotReplicasResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListBotReplicasCommand}.
 */
export interface ListBotReplicasCommandInput extends ListBotReplicasRequest {
}
/**
 * @public
 *
 * The output of {@link ListBotReplicasCommand}.
 */
export interface ListBotReplicasCommandOutput extends ListBotReplicasResponse, __MetadataBearer {
}
declare const ListBotReplicasCommand_base: {
    new (input: ListBotReplicasCommandInput): import("@smithy/smithy-client").CommandImpl<ListBotReplicasCommandInput, ListBotReplicasCommandOutput, LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: ListBotReplicasCommandInput): import("@smithy/smithy-client").CommandImpl<ListBotReplicasCommandInput, ListBotReplicasCommandOutput, LexModelsV2ClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>The action to list the replicated bots.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { LexModelsV2Client, ListBotReplicasCommand } from "@aws-sdk/client-lex-models-v2"; // ES Modules import
 * // const { LexModelsV2Client, ListBotReplicasCommand } = require("@aws-sdk/client-lex-models-v2"); // CommonJS import
 * const client = new LexModelsV2Client(config);
 * const input = { // ListBotReplicasRequest
 *   botId: "STRING_VALUE", // required
 * };
 * const command = new ListBotReplicasCommand(input);
 * const response = await client.send(command);
 * // { // ListBotReplicasResponse
 * //   botId: "STRING_VALUE",
 * //   sourceRegion: "STRING_VALUE",
 * //   botReplicaSummaries: [ // BotReplicaSummaryList
 * //     { // BotReplicaSummary
 * //       replicaRegion: "STRING_VALUE",
 * //       creationDateTime: new Date("TIMESTAMP"),
 * //       botReplicaStatus: "Enabling" || "Enabled" || "Deleting" || "Failed",
 * //       failureReasons: [ // FailureReasons
 * //         "STRING_VALUE",
 * //       ],
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param ListBotReplicasCommandInput - {@link ListBotReplicasCommandInput}
 * @returns {@link ListBotReplicasCommandOutput}
 * @see {@link ListBotReplicasCommandInput} for command's `input` shape.
 * @see {@link ListBotReplicasCommandOutput} for command's `response` shape.
 * @see {@link LexModelsV2ClientResolvedConfig | config} for LexModelsV2Client's `config` shape.
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The service encountered an unexpected condition. Try your request
 *          again.</p>
 *
 * @throws {@link ServiceQuotaExceededException} (client fault)
 *  <p>You have reached a quota for your bot. </p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Your request rate is too high. Reduce the frequency of
 *          requests.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>One of the input parameters in your request isn't valid. Check the
 *          parameters and try your request again.</p>
 *
 * @throws {@link LexModelsV2ServiceException}
 * <p>Base exception class for all service exceptions from LexModelsV2 service.</p>
 *
 * @public
 */
export declare class ListBotReplicasCommand extends ListBotReplicasCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListBotReplicasRequest;
            output: ListBotReplicasResponse;
        };
        sdk: {
            input: ListBotReplicasCommandInput;
            output: ListBotReplicasCommandOutput;
        };
    };
}
